@@ -15,4 +15,4 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-from mapproxy.platform.proj import Proj, transform, set_datapath
\ No newline at end of file
+from mapproxy.platform.proj import Proj, transform, set_datapath, ProjInitError
\ No newline at end of file
